@@ -1,5 +1,6 @@
 /**
  *  @file    main.c
+ *  @ingroup Frontend
  *  @author  Nathan Baker
  *  @brief   APBS "front end" program using formatted input files.
  * 
@@ -13,7 +14,7 @@
  *           where apbs.in is a formatted input file (see documentation and
  *           examples).
  * 
- *  @version $Id: main.c 1260 2008-04-15 18:40:45Z yhuang01 $
+ *  @version $Id: main.c 1351 2009-02-12 01:26:03Z yhuang01 $
  *  @attention
  *  @verbatim
  *
@@ -26,8 +27,8 @@
  *
  * Additional contributing authors listed in the code documentation.
  *
- * Copyright (c) 2002-2008, Washington University in St. Louis.
- * Portions Copyright (c) 2002-2008.  Nathan A. Baker
+ * Copyright (c) 2002-2009, Washington University in St. Louis.
+ * Portions Copyright (c) 2002-2009.  Nathan A. Baker
  * Portions Copyright (c) 1999-2002.  The Regents of the University of California.
  * Portions Copyright (c) 1995.  Michael Holst
  *
@@ -72,11 +73,17 @@
 
 #include "routines.h"
 
-VEMBED(rcsid="$Id: main.c 1260 2008-04-15 18:40:45Z yhuang01 $")
+VEMBED(rcsid="$Id: main.c 1351 2009-02-12 01:26:03Z yhuang01 $")
 
+/** 
+ * @brief The main APBS function
+ * @ingroup  Frontend
+ * @author  Nathan Baker, Dave Gohara, Todd Dolinsky
+ * @returns Status code (0 for success)
+ */
 int main(
-		 int argc, 
-		 char **argv
+		 int argc,  /**< Number of arguments */
+		 char **argv  /**< Argument strings */
 		 ) 
 {
 	
@@ -134,7 +141,7 @@ int main(
 	char header[] = {"\n\n\
 ----------------------------------------------------------------------\n\
 	APBS -- Adaptive Poisson-Boltzmann Solver\n\
-	Version 1.0.0\n\
+	Version 1.1.0\n\
 	\n\
 	Nathan A. Baker (baker@biochem.wustl.edu)\n\
 	Dept. Biochemistry and Molecular Biophysics\n\
@@ -143,8 +150,8 @@ int main(
 	\n\
 	Additional contributing authors listed in the code documentation.\n\
 	\n\
-	Copyright (c) 2002-2008, Washington University in St. Louis.\n\
-	Portions Copyright (c) 2002-2008.  Nathan A. Baker\n\
+	Copyright (c) 2002-2009, Washington University in St. Louis.\n\
+	Portions Copyright (c) 2002-2009.  Nathan A. Baker\n\
 	Portions Copyright (c) 1999-2002.  The Regents of the University of California.\n\
 	Portions Copyright (c) 1995.  Michael Holst\n\
 	\n\
