@@ -9,7 +9,7 @@ Additional APBS-specific features added by Nathan Baker
 Ported to Python/Psize class by Todd Dolinsky and subsequently hacked by
 Nathan Baker
 
-Version:  $Id: psize.py 1251 2008-03-30 22:32:00Z sobolevnrm $
+Version:  $Id: psize.py 1350 2009-02-12 00:38:48Z yhuang01 $
 
 APBS -- Adaptive Poisson-Boltzmann Solver
 
@@ -20,8 +20,8 @@ APBS -- Adaptive Poisson-Boltzmann Solver
 
   Additional contributing authors listed in the code documentation.
 
-Copyright (c) 2002-2008, Washington University in St. Louis.
-Portions Copyright (c) 2002-2008.  Nathan A. Baker
+Copyright (c) 2002-2009, Washington University in St. Louis.
+Portions Copyright (c) 2002-2009.  Nathan A. Baker
 Portions Copyright (c) 1999-2002.  The Regents of the University of California.
 Portions Copyright (c) 1995.  Michael Holst
 
@@ -152,7 +152,7 @@ class Psize:
 		tn = [0,0,0]
 		for i in range(3):
 			tn[i] = int(flen[i]/self.constants["space"] + 0.5)
-			self.n[i] = 32*(int((tn[i] - 1) / 32 + 0.5)) + 1
+			self.n[i] = 32*(int((tn[i] - 1) / 32.0 + 0.5)) + 1
 			if self.n[i] < 33:
 				self.n[i] = 33
 		return self.n
