@@ -18,8 +18,8 @@
 
 	  Additional contributing authors listed in the code documentation.
 
-	Copyright (c) 2002-2008, Washington University in St. Louis.
-	Portions Copyright (c) 2002-2008.  Nathan A. Baker
+	Copyright (c) 2002-2009, Washington University in St. Louis.
+	Portions Copyright (c) 2002-2009.  Nathan A. Baker
 	Portions Copyright (c) 1999-2002.  The Regents of the University of California.
 	Portions Copyright (c) 1995.  Michael Holst
 
@@ -105,7 +105,7 @@ def getHeader():
     header = "\n\n\
     ----------------------------------------------------------------------\n\
     Adaptive Poisson-Boltzmann Solver (APBS)\n\
-    Version 1.0.0\n\
+    Version 1.1.0\n\
     \n\
     APBS -- Adaptive Poisson-Boltzmann Solver\n\
     \n\
@@ -116,8 +116,8 @@ def getHeader():
     \n\
     Additional contributing authors listed in the code documentation.\n\
     \n\
-    Copyright (c) 2002-2008, Washington University in St. Louis.\n\
-    Portions Copyright (c) 2002-2008.  Nathan A. Baker\n\
+    Copyright (c) 2002-2009, Washington University in St. Louis.\n\
+    Portions Copyright (c) 2002-2009.  Nathan A. Baker\n\
     Portions Copyright (c) 1999-2002.  The Regents of the University of California.\n\
     Portions Copyright (c) 1995.  Michael Holst\n\
     \n\
@@ -138,7 +138,7 @@ def getHeader():
       software without specific prior written permission.\n\
     \n\
     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n\
-    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n\
+    \"AS IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n\
     LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\n\
     A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR\n\
     CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\n\
